@@ -10,6 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib import constants
+
+
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
     'allocation_pools',
@@ -38,7 +41,7 @@ KNOWN_ATTRIBUTES = (
     'prefixes',
     'prefixlen',
     'project_id',
-    'shared',
+    constants.SHARED,
     'status',
     'subnets',
     'subnetpool_id',
@@ -88,6 +91,7 @@ KNOWN_EXTENSIONS = (
     'extra_dhcp_opt',
     'extraroute',
     'flavors',
+    'ip-substring-filtering',
     'l3-ha',
     'l3_agent_scheduler',
     'logging',
@@ -112,6 +116,7 @@ KNOWN_EXTENSIONS = (
     'standard-attr-revisions',
     'standard-attr-timestamp',
     'subnet_allocation',
+    'subnet_onboard',
     'tag',
     'trunk',
     'trunk-details',
@@ -124,6 +129,7 @@ KNOWN_EXTENSIONS = (
     'fwaas_v2',
     'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
     'bgpvpn-routes-control',
+    'bgpvpn-vni',
 )
 
 KNOWN_KEYWORDS = (
