@@ -25,6 +25,8 @@ import six
 from neutron_lib._i18n import _
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
+from neutron_lib.plugins import directory
+
 
 LOG = logging.getLogger(__name__)
 
@@ -806,7 +808,7 @@ def _validate_dict_item(key, key_validator, data):
             try:
                 val_func = validators[k]
             except KeyError:
-                msg = _("Validator '%s' does not exist.") % k
+                msg = _("Validator '%s' does not exist") % k
                 LOG.debug(msg)
                 return msg
             val_params = v
@@ -936,21 +938,21 @@ def validate_port_range_or_none(data, valid_values=None):
     data = str(data)
     ports = data.split(':')
     if len(ports) > 2:
-        msg = _("Port range must be two integers separated by a colon.")
+        msg = _("Port range must be two integers separated by a colon")
         LOG.debug(msg)
         return msg
     for p in ports:
         if len(p) == 0:
-            msg = _("Port range must be two integers separated by a colon.")
+            msg = _("Port range must be two integers separated by a colon")
             LOG.debug(msg)
             return msg
         if not netutils.is_valid_port(p):
-            msg = _("Invalid port: %s.") % p
+            msg = _("Invalid port: %s") % p
             LOG.debug(msg)
             return msg
-    if len(ports) > 1 and ports[0] > ports[1]:
+    if len(ports) > 1 and int(ports[0]) > int(ports[1]):
         msg = _("First port in a port range must be lower than the second "
-                "port.")
+                "port")
         LOG.debug(msg)
         return msg
 
@@ -999,7 +1001,8 @@ def validate_subports(data, valid_values=None):
         if segmentation_type == 'inherit':
             return
         segmentation_id = subport.get("segmentation_id")
-        if (not segmentation_type or not segmentation_id) and len(subport) > 1:
+        if ((not segmentation_type or segmentation_id is None)
+                and len(subport) > 1):
             msg = _("Invalid subport details '%s': missing segmentation "
                     "information. Must specify both segmentation_id and "
                     "segmentation_type") % subport
@@ -1011,10 +1014,24 @@ def validate_subports(data, valid_values=None):
                                  "subport": subport["port_id"]}
             LOG.debug(msg)
             return msg
-        if segmentation_id:
+        if segmentation_id is not None:
             segmentations[segmentation_type].add(segmentation_id)
 
 
+def validate_service_plugin_type(data, valid_values=None):
+    """Validates data is a valid service plugin.
+
+    :param data: The service plugin type to validate.
+    :param valid_values: Not used.
+    :returns: None if data is a valid service plugin known to the plugin
+        directory.
+    :raises: InvalidServiceType if data is not a service known by the
+        plugin directory.
+    """
+    if not directory.get_plugin(data):
+        raise n_exc.InvalidServiceType(service_type=data)
+
+
 # Dictionary that maintains a list of validation functions
 validators = {'type:dict': validate_dict,
               'type:dict_or_none': validate_dict_or_none,
@@ -1055,7 +1072,8 @@ validators = {'type:dict': validate_dict,
               'type:integer': validate_integer,
               'type:list_of_unique_strings': validate_list_of_unique_strings,
               'type:list_of_any_key_specs_or_none':
-                  validate_any_key_specs_or_none}
+                  validate_any_key_specs_or_none,
+              'type:service_plugin_type': validate_service_plugin_type}
 
 
 def _to_validation_type(validation_type):
