@@ -12,15 +12,15 @@
 
 """Context: context for security/db session."""
 
+import collections
 import copy
 import datetime
 
 from oslo_context import context as oslo_context
 from oslo_db.sqlalchemy import enginefacade
 
-# TODO(HenryG): replace db/_api.py with the real db/api.py
 from neutron_lib import _policy as policy
-from neutron_lib.db import _api as db_api
+from neutron_lib.db import api as db_api
 
 
 class ContextBase(oslo_context.RequestContext):
@@ -33,14 +33,16 @@ class ContextBase(oslo_context.RequestContext):
     def __init__(self, user_id=None, tenant_id=None, is_admin=None,
                  timestamp=None, tenant_name=None, user_name=None,
                  is_advsvc=None, **kwargs):
-        # NOTE(jamielennox): We maintain these arguments in order for tests
-        # that pass arguments positionally.
-        kwargs.setdefault('user', user_id)
-        kwargs.setdefault('tenant', tenant_id)
-        super(ContextBase, self).__init__(is_admin=is_admin, **kwargs)
+        # NOTE(jamielennox): We maintain this argument in order for tests that
+        # pass arguments positionally.
+        kwargs.setdefault('project_id', tenant_id)
+        # prefer project_name, as that's what's going to be set by
+        # keystone. Fall back to tenant_name if for some reason it's blank.
+        kwargs.setdefault('project_name', tenant_name)
+        super(ContextBase, self).__init__(
+            is_admin=is_admin, user_id=user_id, **kwargs)
 
         self.user_name = user_name
-        self.tenant_name = tenant_name
 
         if not timestamp:
             timestamp = datetime.datetime.utcnow()
@@ -51,55 +53,51 @@ class ContextBase(oslo_context.RequestContext):
         if self.is_admin is None:
             self.is_admin = policy.check_is_admin(self)
 
-    @property
-    def project_id(self):
-        return self.tenant
-
     @property
     def tenant_id(self):
-        return self.tenant
+        return self.project_id
 
     @tenant_id.setter
     def tenant_id(self, tenant_id):
-        self.tenant = tenant_id
+        self.project_id = tenant_id
 
     @property
-    def user_id(self):
-        return self.user
+    def tenant_name(self):
+        return self.project_name
 
-    @user_id.setter
-    def user_id(self, user_id):
-        self.user = user_id
+    @tenant_name.setter
+    def tenant_name(self, tenant_name):
+        self.project_name = tenant_name
 
     def to_dict(self):
         context = super(ContextBase, self).to_dict()
         context.update({
             'user_id': self.user_id,
-            'tenant_id': self.tenant_id,
+            'tenant_id': self.project_id,
             'project_id': self.project_id,
             'timestamp': str(self.timestamp),
-            'tenant_name': self.tenant_name,
-            'project_name': self.tenant_name,
+            'tenant_name': self.project_name,
+            'project_name': self.project_name,
             'user_name': self.user_name,
         })
         return context
 
     def to_policy_values(self):
         values = super(ContextBase, self).to_policy_values()
-        values['tenant_id'] = self.tenant_id
+        values['tenant_id'] = self.project_id
         values['is_admin'] = self.is_admin
 
         # NOTE(jamielennox): These are almost certainly unused and non-standard
         # but kept for backwards compatibility. Remove them in Pike
         # (oslo.context from Ocata release already issues deprecation warnings
         # for non-standard keys).
-        values['user'] = self.user
-        values['tenant'] = self.tenant
-        values['domain'] = self.domain
-        values['user_domain'] = self.user_domain
-        values['project_domain'] = self.project_domain
-        values['tenant_name'] = self.tenant_name
-        values['project_name'] = self.tenant_name
+        values['user'] = self.user_id
+        values['tenant'] = self.project_id
+        values['domain'] = self.domain_id
+        values['user_domain'] = self.user_domain_id
+        values['project_domain'] = self.project_domain_id
+        values['tenant_name'] = self.project_name
+        values['project_name'] = self.project_name
         values['user_name'] = self.user_name
 
         return values
@@ -132,10 +130,15 @@ class ContextBaseWithSession(ContextBase):
     pass
 
 
+_TransactionConstraint = collections.namedtuple(
+    'TransactionConstraint', ['if_revision_match', 'resource', 'resource_id'])
+
+
 class Context(ContextBaseWithSession):
     def __init__(self, *args, **kwargs):
         super(Context, self).__init__(*args, **kwargs)
         self._session = None
+        self._txn_constraint = None
 
     @property
     def session(self):
@@ -144,9 +147,30 @@ class Context(ContextBaseWithSession):
         if hasattr(super(Context, self), 'session'):
             return super(Context, self).session
         if self._session is None:
-            self._session = db_api.get_session()
+            self._session = db_api.get_writer_session()
+
         return self._session
 
+    def set_transaction_constraint(self, resource, resource_id, rev_number):
+        """Set a revision constraint to enforce before resource_id is changed.
+
+        :param resource: Collection name of resource (e.g. ports or networks)
+        :param resource_id: The primary key ID of the individual resource that
+                            should have its revision number matched before
+                            allowing the transaction to proceed.
+        :param rev_number: The revision_number that the resource should be at.
+        """
+
+        self._txn_constraint = _TransactionConstraint(
+            if_revision_match=rev_number, resource=resource,
+            resource_id=resource_id)
+
+    def clear_transaction_constraint(self):
+        self._txn_constraint = None
+
+    def get_transaction_constraint(self):
+        return self._txn_constraint
+
 
 def get_admin_context():
     return Context(user_id=None,
