@@ -515,3 +515,41 @@ class MultipleExceptions(Exception):
         """
         super(MultipleExceptions, self).__init__(*args, **kwargs)
         self.inner_exceptions = exceptions
+
+
+class HostMacAddressGenerationFailure(ServiceUnavailable):
+    """MAC address generation failure for a host.
+
+    :param host: The host MAC address generation failed for.
+    """
+    message = _("Unable to generate unique mac for host %(host)s.")
+
+
+class NetworkMacAddressGenerationFailure(ServiceUnavailable):
+    """An error related to MAC address generation on a network.
+
+        :param net_id: The ID of the network MAC address generation failed on.
+        """
+    message = _("Unable to generate unique mac on network %(net_id)s.")
+
+
+class InvalidServiceType(InvalidInput):
+    """An error due to an invalid service type.
+
+    :param service_type: The service type that's invalid.
+    """
+    message = _("Invalid service type: %(service_type)s.")
+
+
+class NetworkVlanRangeError(NeutronException):
+    message = _("Invalid network VLAN range: '%(vlan_range)s' - '%(error)s'.")
+
+    def __init__(self, **kwargs):
+        # Convert vlan_range tuple to 'start:end' format for display
+        if isinstance(kwargs['vlan_range'], tuple):
+            kwargs['vlan_range'] = "%d:%d" % kwargs['vlan_range']
+        super(NetworkVlanRangeError, self).__init__(**kwargs)
+
+
+class PhysicalNetworkNameError(NeutronException):
+    message = _("Empty physical network name.")
